.. _deployment_ref:

Deployment and MLOps
====================

This reference lists ``sktime`` integrations with deployment and MLOps solutions.

Currently, ``sktime`` natively supports integration with ``mlflow``.

See ``examples/mlflow`` for a notebook tutorial.

MLflow
------

:mod:`aeon.utils.mlflow_sktime`

.. automodule:: aeon.utils.mlflow_sktime
    :no-members:
    :no-inherited-members:

.. currentmodule:: aeon.utils.mlflow_sktime

.. autosummary::
    :toctree: auto_generated/
    :template: function.rst

    get_default_pip_requirements
    get_default_conda_env
    save_model
    log_model
    load_model
